=======
History
=======

0.1.0 (2021-12-28)
------------------

* First version.

0.1.1 (2022-01-06)
------------------

* Fix some typos.

0.1.2 (2022-01-06)
------------------

* Fix some bug on :code:`use_nearPD` argument in function :code:`latentcor`.

0.1.3 (2022-01-07)
------------------

* Fix syntax errors for :code:`jupyter-execute` in README.txt.

0.1.4 (2022-05-23)
------------------

* Fix error for continuous estimation.

0.2.0 (2022-08-16)
------------------

* Increase maximum iteration for positive definiteness adjustment.
* Make function outputs as dictionary.

0.2.1 (2022-08-22)
------------------

* Make output latent correlation matrix as pandas.DataFrame.
* Polish output heatmap.

0.2.2 (2022-08-22)
------------------

* Update README file.

0.2.3 (2022-08-22)
------------------

* Correct update history.

0.2.4 (2022-09-07)
------------------

* Correct incompatible versions.

0.2.5 (2023-11-05)

* Regenerate interpolants for approximation method and fix version compatibility for Python 3.7.